@@ -37,17 +37,7 @@
 #include <ql/methods/finitedifferences/operators/nthorderderivativeop.hpp>
 #include <ql/methods/finitedifferences/operators/secondderivativeop.hpp>
 #include <ql/methods/finitedifferences/solvers/fdmbackwardsolver.hpp>
-
-#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wunused-local-typedefs"
-#endif
-#include <boost/bind.hpp>
-#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
-#pragma GCC diagnostic pop
-#endif
-
-#include <boost/function.hpp>
+#include <ql/functional.hpp>
 #include <numeric>
 
 using namespace QuantLib;
@@ -405,7 +395,7 @@ namespace {
         : vol2_(0.5*vol*vol),
           direction_(direction),
           map_(ext::make_shared<NthOrderDerivativeOp>(
-              direction, 2, nPoints, mesher)),
+              direction, 2, Integer(nPoints), mesher)),
           preconditioner_(SecondDerivativeOp(direction, mesher)
               .mult(Array(mesher->layout()->size(), vol2_))) { }
 
@@ -432,16 +422,17 @@ namespace {
         Disposable<Array> solve_splitting(
             Size direction, const Array& r, Real dt) const {
 
+            using namespace ext::placeholders;
             if (direction == direction_) {
                 BiCGStabResult result =
                     QuantLib::BiCGstab(
-                        boost::function<Disposable<Array>(const Array&)>(
-                            boost::bind(
+                        ext::function<Disposable<Array>(const Array&)>(
+                            ext::bind(
                                 &FdmHeatEquationOp::solve_apply,
                                 this, _1, -dt)),
                         std::max(Size(10), r.size()), 1e-14,
-                        boost::function<Disposable<Array>(const Array&)>(
-                            boost::bind(&FdmLinearOpComposite::preconditioner,
+                        ext::function<Disposable<Array>(const Array&)>(
+                            ext::bind(&FdmLinearOpComposite::preconditioner,
                                         this, _1, dt))
                     ).solve(r, r);
 
@@ -543,9 +534,6 @@ namespace {
                 ext::make_shared<FdmMesherComposite>(
                     ext::make_shared<Predefined1dMesher>(loc));
 
-            const ext::shared_ptr<FdmLinearOpLayout> layout =
-                mesher->layout();
-
             const Array g = mesher->locations(0);
             const Array sT = Exp(g - 0.5*vol*vol*T)*df;
 
